summaryrefslogtreecommitdiffstats
path: root/libkpgp/kpgpui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkpgp/kpgpui.cpp')
-rw-r--r--libkpgp/kpgpui.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/libkpgp/kpgpui.cpp b/libkpgp/kpgpui.cpp
index e0d5bee2..29456046 100644
--- a/libkpgp/kpgpui.cpp
+++ b/libkpgp/kpgpui.cpp
@@ -115,7 +115,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
TQVBoxLayout *topLayout = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
group = new TQVGroupBox( i18n("Warning"), this );
- group->layout()->setSpacing( KDialog::spacingHint() );
+ group->tqlayout()->setSpacing( KDialog::spacingHint() );
// (mmutz) work around Qt label bug in 3.0.0 (and possibly later):
// 1. Don't use rich text: No <qt><b>...</b></qt>
label = new TQLabel( i18n("Please check if encryption really "
@@ -126,13 +126,13 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
labelFont.setBold( true );
label->setFont( labelFont );
// 3. and activate wordwarp:
- label->setAlignment( AlignLeft|WordBreak );
+ label->tqsetAlignment( AlignLeft|WordBreak );
// end; to remove the workaround, add <qt><b>..</b></qt> around the
// text and remove lines TQFont... -> label->setAlignment(...).
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );
- group->layout()->setSpacing( KDialog::spacingHint() );
+ group->tqlayout()->setSpacing( KDialog::spacingHint() );
TQHBox * hbox = new TQHBox( group );
label = new TQLabel( i18n("Select encryption tool to &use:"), hbox );
@@ -153,7 +153,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
topLayout->addWidget( group );
mpOptionsGroupBox = new TQVGroupBox( i18n("Options"), this );
- mpOptionsGroupBox->layout()->setSpacing( KDialog::spacingHint() );
+ mpOptionsGroupBox->tqlayout()->setSpacing( KDialog::spacingHint() );
storePass = new TQCheckBox( i18n("&Keep passphrase in memory"),
mpOptionsGroupBox );
connect( storePass, TQT_SIGNAL( toggled( bool ) ),
@@ -1176,7 +1176,7 @@ KeyRequester::KeyRequester( TQWidget * parent, bool multipleKeys,
// the button to unset any key:
mEraseButton = new TQPushButton( this );
mEraseButton->setAutoDefault( false );
- mEraseButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
+ mEraseButton->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
TQSizePolicy::Minimum ) );
mEraseButton->setPixmap( SmallIcon( "clear_left" ) );
TQToolTip::add( mEraseButton, i18n("Clear") );
@@ -1192,7 +1192,7 @@ KeyRequester::KeyRequester( TQWidget * parent, bool multipleKeys,
connect( mEraseButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEraseButtonClicked()) );
connect( mDialogButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotDialogButtonClicked()) );
- setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
+ tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
TQSizePolicy::Fixed ) );
}
@@ -1480,21 +1480,21 @@ KeyApprovalDialog::KeyApprovalDialog( const TQStringList& addresses,
// calculate the optimal width for the dialog
int dialogWidth = marginHint()
+ sv->frameWidth()
- + bigvbox->sizeHint().width()
- + sv->verticalScrollBar()->sizeHint().width()
+ + bigvbox->tqsizeHint().width()
+ + sv->verticalScrollBar()->tqsizeHint().width()
+ sv->frameWidth()
+ marginHint()
+ 2;
// calculate the optimal height for the dialog
int dialogHeight = marginHint()
- + label->sizeHint().height()
+ + label->tqsizeHint().height()
+ topLayout->spacing()
+ sv->frameWidth()
- + bigvbox->sizeHint().height()
- + sv->horizontalScrollBar()->sizeHint().height()
+ + bigvbox->tqsizeHint().height()
+ + sv->horizontalScrollBar()->tqsizeHint().height()
+ sv->frameWidth()
+ topLayout->spacing()
- + actionButton( KDialogBase::Cancel )->sizeHint().height()
+ + actionButton( KDialogBase::Cancel )->tqsizeHint().height()
+ marginHint()
+ 2;
// don't make the dialog too large
@@ -1630,26 +1630,26 @@ CipherTextDialog::CipherTextDialog( const TQCString & text,
mEditBox->setReadOnly(true);
topLayout->addWidget( mEditBox, 10 );
- TQString unicodeText;
+ TQString tqunicodeText;
if (charset.isEmpty())
- unicodeText = TQString::fromLocal8Bit(text.data());
+ tqunicodeText = TQString::fromLocal8Bit(text.data());
else {
bool ok=true;
TQTextCodec *codec = KGlobal::charsets()->codecForName(charset, ok);
if(!ok)
- unicodeText = TQString::fromLocal8Bit(text.data());
+ tqunicodeText = TQString::fromLocal8Bit(text.data());
else
- unicodeText = codec->toUnicode(text.data(), text.length());
+ tqunicodeText = codec->toUnicode(text.data(), text.length());
}
- mEditBox->setText(unicodeText);
+ mEditBox->setText(tqunicodeText);
setMinimumSize();
}
void CipherTextDialog::setMinimumSize()
{
// this seems to force a layout of the entire document, so we get a
// a proper contentsWidth(). Is there a better way?
for ( int i = 0; i < mEditBox->paragraphs(); i++ )
(void) mEditBox->paragraphRect( i );
@@ -1660,7 +1660,7 @@ void CipherTextDialog::setMinimumSize()
#if KDE_IS_VERSION( 3, 1, 90 )
- int maxWidth = KGlobalSettings::desktopGeometry(parentWidget()).width()-100;
+ int maxWidth = KGlobalSettings::desktopGeometry(tqparentWidget()).width()-100;
#else
KConfig gc("kdeglobals", false, false);
gc.setGroup("Windows");
@@ -1668,9 +1668,9 @@ void CipherTextDialog::setMinimumSize()
if (TQApplication::desktop()->isVirtualDesktop() &&
gc.readBoolEntry("XineramaEnabled", true) &&
gc.readBoolEntry("XineramaPlacementEnabled", true)) {
- maxWidth = TQApplication::desktop()->screenGeometry(TQApplication::desktop()->screenNumber(parentWidget())).width()-100;
+ maxWidth = TQApplication::desktop()->screenGeometry(TQApplication::desktop()->screenNumber(tqparentWidget())).width()-100;
} else {
- maxWidth = TQApplication::desktop()->geometry().width()-100;
+ maxWidth = TQApplication::desktop()->tqgeometry().width()-100;
}
#endif
@@ -126,13 +126,13 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
// end; to remove the workaround, add <qt><b>..</b></qt> around the
- // text and remove lines TQFont... -> label->setAlignment(...).
+ // text and remove lines TQFont... -> label->tqsetAlignment(...).
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );
@@ -1630,26 +1630,26 @@ CipherTextDialog::CipherTextDialog( const TQCString & text,
void CipherTextDialog::setMinimumSize()
{
- // this seems to force a layout of the entire document, so we get a
+ // this seems to force a tqlayout of the entire document, so we get a
// a proper contentsWidth(). Is there a better way?
for ( int i = 0; i < mEditBox->paragraphs(); i++ )